.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.api:

============
 Python API
============

A software package for Computer-Aided Detection and Segmentation from Medical Data.

.. autosummary::
   :toctree: api
   :recursive:
   :template: mednet/module.rst

   mednet
